@@ -10,7 +10,7 @@ from flask.ext.appbuilder import translations
 from menu import Menu
 
 
-class BaseApp():
+class BaseApp(object):
     """
         This is the base class for the all framework.
         Will hold your flask app object, all your views, and security classes.
@@ -220,10 +220,10 @@ class BaseApp():
             self._add_permission(baseview)
 
     def _add_permission(self, baseview):
-        try:
+        #try:
             self.sm.add_permissions_view(baseview.base_permissions, baseview.__class__.__name__)
-        except:
-            print "Add Permission on View Error: DB not created?"
+        #except:
+        #    print "Add Permission on View Error: DB not created?"
         
     def register_blueprint(self, baseview, endpoint = None, static_folder = None):
         self.app.register_blueprint(baseview.create_blueprint(self,  endpoint = endpoint, static_folder = static_folder))
