@@ -1,4 +1,4 @@
-from flask.ext.babel import lazy_gettext
+from flask.ext.babelpkg import lazy_gettext
 
 class BaseFilter(object):
 
@@ -174,9 +174,6 @@ class Filters(object):
                     FilterGreater(col, datamodel), 
                     FilterSmaller(col, datamodel),
                     FilterNotEqual(col, datamodel)]
-            elif datamodel.is_boolean(col):
-                return [FilterEqual(col, datamodel),
-                    FilterNotEqual(col, datamodel)]
             else:
                 print "Filter type not supported for column: %s" % (col)
                 return None
@@ -227,7 +224,7 @@ class Filters(object):
                 return value
 
     def get_filters_values_tojson(self):
-        return [(flt.column_name, flt.name.encode('utf-8'), value) for flt, value in zip(self.filters, self.values)]
+        return [(flt.column_name, unicode(flt.name), value) for flt, value in zip(self.filters, self.values)]
 
     def apply_all(self, query):
         for flt, value in zip(self.filters, self.values):
