@@ -63,9 +63,9 @@ class SearchWidget(FormWidget):
         search_filters = {}
         dict_filters = self.filters.get_search_filters()
         for col in self.include_cols:
-            label_columns[col] = self.form[col].label.text.encode('utf-8')
+            label_columns[col] = unicode(self.form[col].label.text)
             form_fields[col] = self.form[col]()
-            search_filters[col] = [flt.name.encode('utf-8') for flt in dict_filters[col]]                
+            search_filters[col] = [unicode(flt.name) for flt in dict_filters[col]]                
 
         kwargs['label_columns'] = label_columns
         kwargs['form_fields'] = form_fields
@@ -83,7 +83,7 @@ class ShowWidget(RenderTemplateWidget):
     label_columns = []
     include_columns = []
     value_columns = []
-    additional_links = []
+    actions = None
     fieldsets = []
 
     def __init__(self, route_base = '',
@@ -91,14 +91,14 @@ class ShowWidget(RenderTemplateWidget):
                 label_columns = [],
                 include_columns = [],
                 value_columns = [],
-                additional_links = [],
+                actions = None,
                 fieldsets = []):
         self.route_base = route_base
         self.pk = pk
         self.label_columns = label_columns
         self.include_columns = include_columns
         self.value_columns = value_columns
-        self.additional_links = additional_links
+        self.actions = actions
         self.fieldsets = fieldsets
 
     def __call__(self, **kwargs):
@@ -107,7 +107,7 @@ class ShowWidget(RenderTemplateWidget):
         kwargs['label_columns'] = self.label_columns
         kwargs['include_columns'] = self.include_columns
         kwargs['value_columns'] = self.value_columns
-        kwargs['additional_links'] = self.additional_links
+        kwargs['actions'] = self.actions
         kwargs['fieldsets'] = self.fieldsets
         return super(ShowWidget, self).__call__(**kwargs)
 
@@ -125,6 +125,7 @@ class ListWidget(RenderTemplateWidget):
     page_size = None
     count = 0
     pks = []
+    actions = None
     filters = {}
     generalview_name = ''
 
@@ -137,6 +138,7 @@ class ListWidget(RenderTemplateWidget):
                  page_size = None,
                  count = 0,
                  pks = [],
+                 actions = None,
                  filters = {},
                  generalview_name = ''):
         self.route_base = route_base
@@ -148,6 +150,7 @@ class ListWidget(RenderTemplateWidget):
         self.page_size = page_size
         self.count = count
         self.pks = pks
+        self.actions = actions
         self.filters = filters
         self.generalview_name = generalview_name
 
@@ -163,6 +166,7 @@ class ListWidget(RenderTemplateWidget):
         kwargs['count'] = self.count
         
         kwargs['pks'] = self.pks
+        kwargs['actions'] = self.actions
         kwargs['filters'] = self.filters
         kwargs['generalview_name'] = self.generalview_name
         return super(ListWidget, self).__call__(**kwargs)
